import smtplib
from email.mime.application import MIMEApplication
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText

import psycopg.rows

from model.settings import settings


def get_cursor(conn):
    return conn.cursor(row_factory=psycopg.rows.dict_row)


def send_email(to: str | list[str], sender: str, cc=None, bcc=None, reply_to=None, subject=None, body=None,
               body_type: str = 'html', attachments: list[MIMEApplication] = None):
    if type(to) is not list:
        to = to.split(',')

    to_list = [x for x in to if x is not None]

    msg = MIMEMultipart()
    msg['From'] = sender
    msg['Subject'] = subject
    msg['To'] = ','.join(to_list)
    if cc is not None:
        msg['Cc'] = cc
    if bcc is not None:
        msg['Bcc'] = bcc
    msg['X-Auto-Response-Suppress'] = 'All'
    # if 'lists.kit.edu' not in msg['To']:
    #     # this should probably be turned on but mailing-lists sometimes ignore mails with this activated...
    #     msg['Auto-Submitted'] = 'auto-generated'
    msg['Reply-To'] = reply_to
    msg.attach(MIMEText(body, body_type))
    for attachment in attachments or []:
        msg.attach(attachment)
    with smtplib.SMTP(settings.mail_smarthost) as server:
        server.sendmail(sender, to_list, msg.as_string())


def map_array_of_dicts(input_array, key_fun):
    result_dict = {}

    for item in input_array:
        key_value = key_fun(item)

        if key_value is not None:
            if key_value not in result_dict:
                result_dict[key_value] = []
            result_dict[key_value].append(item)

    return result_dict
